@@ -114,6 +114,9 @@ def get_current_user_from_token(token: str):
     try:
         decoded = auth.verify_id_token(token)
         current_user = CurrentUser(**decoded)
+        print(
+            f"Current User: {current_user.uid}, name: {current_user.display_name}, phone_number: {current_user.phone_number}"
+        )
         return current_user
     except firebase_admin._token_gen.ExpiredIdTokenError as e:
         print("DOORMAN ERROR", e)
